@@ -2,6 +2,20 @@ package Data::Object;
 
 use 5.014;
 
+use strict;
+use warnings;
+use routines;
+
+fun import($class, @args) {
+
+  "Data::Object::Keyword"->import($class, @args);
+}
+
+package
+  Data::Object::Keyword;
+
+use 5.014;
+
 use strict;
 use warnings;
 
@@ -10,7 +24,7 @@ use routines;
 
 use parent 'Exporter';
 
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.03'; # VERSION
 
 our @EXPORT = qw(
   Array
@@ -28,8 +42,34 @@ our @EXPORT = qw(
   Undef
 );
 
+our @EXPORT_OK = (@EXPORT, qw(
+  Args
+  Data
+  Opts
+  Name
+  Space
+  Struct
+  Vars
+));
+
+# IMPORT
+
+fun import($class, @args) {
+  if (caller eq "Data::Object") {
+    "Data::Object::Keyword"->export_to_level(2, @args);
+  }
+}
+
 # FUNCTIONS
 
+fun Args(Maybe[HashRef] $data) {
+  $data //= {};
+
+  require Data::Object::Args;
+
+  return Data::Object::Args->new(named => $data);
+}
+
 fun Array(Maybe[ArrayRef] $data) {
   $data //= [];
 
@@ -61,6 +101,14 @@ fun Code(Maybe[CodeRef] $data) {
   return Box(Data::Object::Code->new($data));
 }
 
+fun Data(Maybe[Str] $data) {
+  $data //= $0;
+
+  require Data::Object::Data;
+
+  return Data::Object::Data->new(file => $data);
+}
+
 fun False() {
 
   require Data::Object::Boolean;
@@ -84,6 +132,14 @@ fun Hash(Maybe[HashRef] $data) {
   return Box(Data::Object::Hash->new($data));
 }
 
+fun Name(Maybe[Str] $data) {
+  $data //= '';
+
+  require Data::Object::Name;
+
+  return Data::Object::Name->new($data);
+}
+
 fun Number(Maybe[Num] $data) {
   $data //= 1;
 
@@ -92,6 +148,14 @@ fun Number(Maybe[Num] $data) {
   return Box(Data::Object::Number->new($data));
 }
 
+fun Opts(Maybe[HashRef] $data) {
+  $data //= {};
+
+  require Data::Object::Opts;
+
+  return Data::Object::Opts->new($data);
+}
+
 fun Regexp(Maybe[RegexpRef] $data) {
   $data //= qr/.*/;
 
@@ -108,6 +172,14 @@ fun Scalar(Maybe[Ref] $data) {
   return Box(Data::Object::Scalar->new($data));
 }
 
+fun Space(Maybe[Str] $data) {
+  $data //= 'main';
+
+  require Data::Object::Space;
+
+  return Data::Object::Space->new($data);
+}
+
 fun String(Maybe[Str] $data) {
   $data //= '';
 
@@ -116,6 +188,14 @@ fun String(Maybe[Str] $data) {
   return Box(Data::Object::String->new($data));
 }
 
+fun Struct(Maybe[HashRef] $data) {
+  $data //= {};
+
+  require Data::Object::Struct;
+
+  return Box(Data::Object::Struct->new($data));
+}
+
 fun True() {
 
   require Data::Object::Boolean;
@@ -130,6 +210,14 @@ fun Undef() {
   return Box(Data::Object::Undef->new);
 }
 
+fun Vars(Maybe[HashRef] $data) {
+  $data //= {};
+
+  require Data::Object::Vars;
+
+  return Data::Object::Vars->new(named => $data);
+}
+
 1;
 
 =encoding utf8
@@ -181,6 +269,40 @@ This package implements the following functions:
 
 =cut
 
+=head2 args
+
+  Args(HashRef $data) : InstanceOf["Data::Object::Args"]
+
+The Args function returns a L<Data::Object::Args> object.
+
+=over 4
+
+=item Args example #1
+
+  package main;
+
+  use Data::Object 'Args';
+
+  my $args = Args; # [...]
+
+=back
+
+=over 4
+
+=item Args example #2
+
+  package main;
+
+  my $args = Args {
+    subcommand => 0
+  };
+
+  # $args->subcommand;
+
+=back
+
+=cut
+
 =head2 array
 
   Array(ArrayRef $data) : InstanceOf["Data::Object::Box"]
@@ -317,6 +439,38 @@ L<Data::Object::Code> object.
 
 =cut
 
+=head2 data
+
+  Data(Str $file) : InstanceOf["Data::Object::Data"]
+
+The Data function returns a L<Data::Object::Data> object.
+
+=over 4
+
+=item Data example #1
+
+  package main;
+
+  use Data::Object 'Data';
+
+  my $data = Data;
+
+=back
+
+=over 4
+
+=item Data example #2
+
+  package main;
+
+  my $data = Data '/path/to/file.pod';
+
+  # $data->contents(...);
+
+=back
+
+=cut
+
 =head2 false
 
   False() : BooleanObject
@@ -394,6 +548,28 @@ L<Data::Object::Hash> object.
 
 =cut
 
+=head2 name
+
+  Name(Str $data) : InstanceOf["Data::Object::Name"]
+
+The Name function returns a L<Name::Object::Name> object.
+
+=over 4
+
+=item Name example #1
+
+  package main;
+
+  use Data::Object 'Name';
+
+  my $name = Name 'Example Title';
+
+  # $name->package;
+
+=back
+
+=cut
+
 =head2 number
 
   Number(Num $data) : InstanceOf["Data::Object::Box"]
@@ -423,6 +599,38 @@ L<Data::Object::Number> object.
 
 =cut
 
+=head2 opts
+
+  Opts(HashRef $data) : InstanceOf["Data::Object::Opts"]
+
+The Opts function returns a L<Data::Object::Opts> object.
+
+=over 4
+
+=item Opts example #1
+
+  package main;
+
+  my $opts = Opts;
+
+=back
+
+=over 4
+
+=item Opts example #2
+
+  package main;
+
+  my $opts = Opts {
+    spec => ['files|f=s']
+  };
+
+  # $opts->files; [...]
+
+=back
+
+=cut
+
 =head2 regexp
 
   Regexp(RegexpRef $data) : InstanceOf["Data::Object::Box"]
@@ -481,6 +689,26 @@ L<Data::Object::Scalar> object.
 
 =cut
 
+=head2 space
+
+  Space(Str $data) : InstanceOf["Data::Object::Space"]
+
+The Space function returns a L<Data::Object::Space> object.
+
+=over 4
+
+=item Space example #1
+
+  package main;
+
+  use Data::Object 'Space';
+
+  my $space = Space 'Example Namespace';
+
+=back
+
+=cut
+
 =head2 string
 
   String(Str $data) : InstanceOf["Data::Object::Box"]
@@ -510,6 +738,39 @@ L<Data::Object::String> object.
 
 =cut
 
+=head2 struct
+
+  Struct(HashRef $data) : InstanceOf["Data::Object::Struct"]
+
+The Struct function returns a L<Data::Object::Struct> object.
+
+=over 4
+
+=item Struct example #1
+
+  package main;
+
+  use Data::Object 'Struct';
+
+  my $struct = Struct;
+
+=back
+
+=over 4
+
+=item Struct example #2
+
+  package main;
+
+  my $struct = Struct {
+    name => 'example',
+    time => time
+  };
+
+=back
+
+=cut
+
 =head2 true
 
   True() : BooleanObject
@@ -548,6 +809,41 @@ I<undefined> value.
 
 =cut
 
+=head2 vars
+
+  Vars() : InstanceOf["Data::Object::Vars"]
+
+The Vars function returns a L<Data::Object::Vars> object representing the
+available environment variables.
+
+=over 4
+
+=item Vars example #1
+
+  package main;
+
+  use Data::Object 'Vars';
+
+  my $vars = Vars;
+
+=back
+
+=over 4
+
+=item Vars example #2
+
+  package main;
+
+  my $vars = Vars {
+    user => 'USER'
+  };
+
+  # $vars->user; # $USER
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Al Newkirk, C<awncorp@cpan.org>
